@@ -1,7 +1,7 @@
 package File::Trash::Undoable;
 
-our $DATE = '2014-12-19'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $DATE = '2015-02-06'; # DATE
+our $VERSION = '0.16'; # VERSION
 
 use 5.010001;
 use strict;
@@ -243,7 +243,7 @@ File::Trash::Undoable - Trash files, with undo/redo capability
 
 =head1 VERSION
 
-This document describes version 0.15 of File::Trash::Undoable (from Perl distribution File-Trash-Undoable), released on 2014-12-19.
+This document describes version 0.16 of File::Trash::Undoable (from Perl distribution File-Trash-Undoable), released on 2015-02-06.
 
 =head1 SYNOPSIS
 
@@ -261,12 +261,10 @@ Screenshots:
 
 =head2 empty_trash() -> [status, msg, result, meta]
 
-Empty trash.
+{en_US Empty trash}.
 
 No arguments.
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -276,17 +274,15 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 list_trash_contents() -> [status, msg, result, meta]
 
-List contents of trash directory.
+{en_US List contents of trash directory}.
 
 No arguments.
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -296,16 +292,18 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 trash(%args) -> [status, msg, result, meta]
 
-Trash a file.
+{en_US Trash a file}.
 
+{en_US 
 Fixed state: path does not exist.
 
 Fixable state: path exists.
+}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -346,8 +344,6 @@ For more information on transaction, see L<Rinci::Transaction>.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -357,12 +353,12 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 trash_files(%args) -> [status, msg, result, meta]
 
-Trash files (with undo support).
+{en_US Trash files (with undo support)}.
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -371,11 +367,13 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<files>* => I<array>
+=item * B<files>* => I<array[str]>
 
-Files/dirs to delete.
+{en_US Files/dirs to delete}.
 
+{en_US 
 Files must exist.
+}
 
 =back
 
@@ -405,8 +403,6 @@ For more information on transaction, see L<Rinci::Transaction>.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -416,17 +412,19 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 untrash(%args) -> [status, msg, result, meta]
 
-Untrash a file.
+{en_US Untrash a file}.
 
+{en_US 
 Fixed state: path exists.
 
 Fixable state: Path does not exist (and exists in trash, and if suffix is
 specified, has the same suffix).
+}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -467,8 +465,6 @@ For more information on transaction, see L<Rinci::Transaction>.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -478,7 +474,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =for HTML <p><img src="http://blogs.perl.org/users/perlancar/screenshot-trashu.jpg" /><br />
 
@@ -524,7 +520,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
